@@ -238,6 +238,19 @@ class BaseGlyph(BaseObject,
             65
             >>> glyph.unicode = None
 
+        This is equivalent to ``glyph.unicodes[0]``. Setting a
+        ``glyph.unicode`` value will reset ``glyph.unicodes`` to a tuple
+        containing that value or an empty tuple if ``value`` is ``None``.
+
+            >>> glyph.unicodes
+            (65, 67)
+            >>> glyph.unicode = 65
+            >>> glyph.unicodes
+            (65,)
+            >>> glyph.unicode = None
+            >>> glyph.unicodes
+            ()
+
         The returned value will be an :ref:`type-int` or ``None``.
         When setting you may send :ref:`type-int` or :ref:`type-hex`
         values or ``None``.
@@ -276,11 +289,10 @@ class BaseGlyph(BaseObject,
 
         Subclasses may override this method.
         """
-        values = list(self.unicodes)
-        if value in values:
-            values.remove(value)
-        values.insert(0, value)
-        self.unicodes = values
+        if value is None:
+            self.unicodes = []
+        else:
+            self.unicodes = [value]
 
     def autoUnicodes(self):
         """
@@ -849,11 +861,13 @@ class BaseGlyph(BaseObject,
 
         Subclasses may override this method.
         """
-        copy = contour.copy()
-        if offset != (0, 0):
-            copy.moveBy(offset)
         pointPen = self.getPointPen()
-        contour.drawPoints(pointPen)
+        if offset != (0, 0):
+            copy = contour.copy()
+            copy.moveBy(offset)
+            copy.drawPoints(pointPen)
+        else:
+            contour.drawPoints(pointPen)
         return self[-1]
 
     def removeContour(self, contour):
@@ -905,6 +919,7 @@ class BaseGlyph(BaseObject,
 
         The behavior of this may vary across environments.
         """
+        self._removeOverlap()
 
     def _removeOverlap(self):
         """
@@ -1463,8 +1478,8 @@ class BaseGlyph(BaseObject,
             anchor.round()
         for guideline in self.guidelines:
             guideline.round()
-        self.width = normalizers.normalizeRounding(self.width)
-        self.height = normalizers.normalizeRounding(self.height)
+        self.width = normalizers.normalizeVisualRounding(self.width)
+        self.height = normalizers.normalizeVisualRounding(self.height)
 
     def correctDirection(self, trueType=False):
         """
@@ -1597,14 +1612,6 @@ class BaseGlyph(BaseObject,
                 color=guideline.color
             )
             mathGlyph.guidelines.append(d)
-        image = self.image
-        mathGlyph.image = dict(
-            # MathGlyph works with image file names, hack
-            # around it by using the data as the file name.
-            fileName=image.data,
-            transformation=image.transformation,
-            color=image.color
-        )
         mathGlyph.lib = deepcopy(self.lib)
         mathGlyph.name = self.name
         mathGlyph.unicodes = self.unicodes
@@ -1656,12 +1663,6 @@ class BaseGlyph(BaseObject,
             identifier = guideline.get("identifier")
             if identifier is not None:
                 g._setIdentifier(identifier)
-        data = mathGlyph.image["fileName"]  # see _toMathGlyph
-        if data is not None:
-            image = self.image
-            image.data = data
-            image.transformation = mathGlyph.image["transformation"]
-            image.color = mathGlyph.image["color"]
         copied.lib.update(mathGlyph.lib)
         if not toThisGlyph:
             copied.name = mathGlyph.name
