@@ -1,6 +1,5 @@
 import unittest
 import collections
-from fontTools.misc.py23 import basestring
 from fontParts.base import FontPartsError
 from .test_image import testImageData
 
@@ -121,19 +120,28 @@ class TestGlyph(unittest.TestCase):
         for value in valid_uni_values:
             glyph = self.get_generic_object("glyph")
             glyph.unicode = value
-            result = int(value, 16) if isinstance(value, basestring) else value
+            result = int(value, 16) if isinstance(value, str) else value
             self.assertEqual(
                 glyph.unicode,
                 result
             )
 
-    def test_set_unicode_primary_value(self):
+    def test_set_unicode_value(self):
         glyph = self.get_generic_object("glyph")
         glyph.unicodes = (10, 20)
         glyph.unicode = 20
         self.assertEqual(
             glyph.unicodes,
-            (20, 10)
+            (20,)
+        )
+
+    def test_set_unicode_value_none(self):
+        glyph = self.get_generic_object("glyph")
+        glyph.unicodes = (10, 20)
+        glyph.unicode = None
+        self.assertEqual(
+            glyph.unicodes,
+            ()
         )
 
     def test_set_unicode_invalid(self):
@@ -396,9 +404,19 @@ class TestGlyph(unittest.TestCase):
     def test_appendContour_offset_valid(self):
         glyph = self.getGlyph_generic()
         contour = self.get_generic_object("contour")
-        glyph.appendContour(contour, (50, 50))
+        contour.insertPoint(0,position=(0,0))
+        contour.insertPoint(1,position=(100,100))
+        contour.insertPoint(2,position=(0,100))
+
+        self.assertEqual(len(glyph), 2)
+        newcontour = glyph.appendContour(contour, (45, 50))
         self.assertEqual(len(glyph), 3)
 
+        self.assertEqual(newcontour, glyph[-1])
+        self.assertEqual(len(newcontour.points),3)
+        self.assertEqual(newcontour.points[0].x, 45)
+        self.assertEqual(newcontour.points[0].y, 50)
+
     def test_removeContour_valid(self):
         glyph = self.getGlyph_generic()
         contour = self.get_generic_object("contour")
@@ -808,6 +826,7 @@ class TestGlyph(unittest.TestCase):
             ()
         )
 
+
     # Components
 
     def test_selectedComponents_default(self):
@@ -1151,6 +1170,12 @@ class TestGlyph(unittest.TestCase):
         glyph.appendComponent("component 1")
         self.assertFalse(glyph.isEmpty())
 
+    def test_removeOverlap(self):
+        glyph = self.getGlyph_generic()
+        self.assertEquals(len(glyph), 2)
+        glyph.removeOverlap()
+        self.assertEquals(len(glyph), 1)
+
 
 def test_generator(test_name, metric, value):
     if '_invalid_' in test_name:
